# User Guide

Learn how to use Rapporto.

```{toctree}
:maxdepth: 1
:hidden:

github
slack
```

::::{grid} 2

:::{grid-item-card}
:link: github
:link-type: doc
:class-body: sd-text-center sd-fs-3 sd-font-weight-bold
:class-footer: sd-fs-6
GitHub

{fab}`github;sd-text-warning fa-2xl`
+++
Tap into the GitHub API and generate reports in Markdown format.
:::

:::{grid-item-card}
:link: slack
:link-type: doc
:class-body: sd-text-center sd-fs-3 sd-font-weight-bold
:class-footer: sd-fs-6
Slack

{fab}`slack;sd-text-success fa-2xl`
+++
Tap into the Slack API and export threads into Markdown format.
:::

::::
